==> haskell-ormolu-0.5.1.0-33-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.5.1.0
visibility:           public
id:                   ormolu-0.5.1.0-JR2q0nJFsTi5k1hDWfNOzt
key:                  ormolu-0.5.1.0-JR2q0nJFsTi5k1hDWfNOzt
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  87f2974595f5d30e3d3671342d51f178
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.5.1.0-JR2q0nJFsTi5k1hDWfNOzt
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    MemoTrie-0.6.11-7E0QLaDoThOCK6LpEoOfn8
    aeson-2.1.2.1-DzmMfEZgdOFRIaYChwLwW
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En mtl-2.2.2
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-7x3aJxt6vZXGANjpY7X1Vm

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ormolu-0.5.1.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.5.1.0
visibility:           public
id:                   ormolu-0.5.1.0-DUrhnjIhD8g8eVGtf0PxJu
key:                  ormolu-0.5.1.0-DUrhnjIhD8g8eVGtf0PxJu
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  50caf64840628889111b84239a0bbb44
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.5.1.0-DUrhnjIhD8g8eVGtf0PxJu
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-LlG9CqI0BWmDdGO3rVr0iN
    MemoTrie-0.6.11-7E0QLaDoThOCK6LpEoOfn8
    aeson-2.1.2.1-9BF5sjMs3G4H72EdbKHz4V
    ansi-terminal-1.0.2-6TxOAUbfOQrDbPnWIRhRhS array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-KkOPmPbRCEmCvB2XbKT9En mtl-2.2.2
    syb-0.7.2.4-HJAbU0lurQkHN7nU4EHwhb template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-7x3aJxt6vZXGANjpY7X1Vm

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
